@@ -3,13 +3,11 @@ use strict;
 use warnings;
 
 package WWW::Shopify::Liquid::Filter::MD5; use base 'WWW::Shopify::Liquid::Filter';
-use Storable qw(freeze);
 use Digest::MD5 qw(md5_hex);
-$Storable::canonical = 1;
-use Data::Dumper;
+use JSON qw(to_json);
 sub operate {
 	my ($self, $hash, $operand, @arguments) = @_;
-	return md5_hex(freeze($operand)) if ref($operand);
+	return md5_hex(to_json($operand, { canonical => 1 })) if ref($operand);
 	return md5_hex($operand);
 }
 
